summaryrefslogtreecommitdiffstats
path: root/make_slackware_live.sh
diff options
context:
space:
mode:
author Eric Hameleers <alien@slackware.com>2016-12-15 23:10:57 +0100
committer Eric Hameleers <alien@slackware.com>2016-12-15 23:10:57 +0100
commit8418050bff2e2b69606516bc3e082965cc073c9a (patch)
treefbaaf235b46cb07f495f19245a62125634ad9fc9 /make_slackware_live.sh
parent875f345a85e25e6fa1b29c2d096478bcd7a02bfd (diff)
downloadliveslak-8418050bff2e2b69606516bc3e082965cc073c9a.tar.gz
liveslak-8418050bff2e2b69606516bc3e082965cc073c9a.tar.xz
DLACK: add Dlackware as a DE choice when generating the ISO.
Dlackware is Slackware with systemd and Gnome3. An interesting experiment. Thanks to bartgymnast of the Dlackware team who provided the patches. Note: at this moment, this is pre-alpha quality. - The default root and live passwords do not work so you'll have to add boot parameter 'livepw=XXXXXXXX' and think of a strong password that passes the PAM strength test. - The Gnome3 environment does not show an application menu. - The Dlackware package quality is sub-standard. Notably it will mess with the buildhost machine's password database and install 64bit stuff into /usr/lib
Diffstat (limited to 'make_slackware_live.sh')
-rwxr-xr-xmake_slackware_live.sh28
1 files changed, 25 insertions, 3 deletions
diff --git a/make_slackware_live.sh b/make_slackware_live.sh
index 7cee8e3..a2817e9 100755
--- a/make_slackware_live.sh
+++ b/make_slackware_live.sh
@@ -94,7 +94,7 @@ DISTRO=${DISTRO:-"slackware"}
LIVE_HOSTNAME=${LIVE_HOSTNAME:-"darkstar"}
# What type of Live image?
# Choices are: SLACKWARE, XFCE, KDE4, PLASMA5, MATE, CINNAMON
LIVEDE=${LIVEDE:-"SLACKWARE"}
# What runlevel to use if adding a DE like: XFCE, KDE4, PLASMA5 etc...
@@ -182,6 +182,10 @@ SEQ_MSB="tagfile:a,ap,d,e,f,k,l,n,t,tcl,x,xap,xfce,y pkglist:slackextra,mate loc
# - each will become a squashfs module:
SEQ_CIN="tagfile:a,ap,d,e,f,k,l,n,t,tcl,x,xap,xfce,y pkglist:slackextra,cinnamon local:slackpkg+"
+# Slackware package series with Gnome3/systemd instead of KDE4 (full install):
+# - each will become a squashfs module:
+SEQ_DLACK="tagfile:a,ap,d,e,f,k,l,n,t,tcl,x,xap pkglist:slackextra,systemd,dlackware"
+
# List of kernel modules required for a live medium to boot properly;
# Lots of HID modules added to support keyboard input for LUKS password entry:
KMODS=${KMODS:-"squashfs:overlay:loop:xhci-pci:ohci-pci:ehci-pci:xhci-hcd:uhci-hcd:ehci-hcd:usb-storage:hid:usbhid:i2c-hid:hid-generic:hid-cherry:hid-logitech:hid-logitech-dj:hid-logitech-hidpp:hid-lenovo:hid-microsoft:hid_multitouch:jbd:mbcache:ext3:ext4:isofs:fat:nls_cp437:nls_iso8859-1:msdos:vfat"}
@@ -758,8 +762,8 @@ do
echo " -h This help."
echo " -a arch Machine architecture (default: ${SL_ARCH})."
echo " Use i586 for a 32bit ISO, x86_64 for 64bit."
- echo " -d desktoptype SLACKWARE (full Slack), KDE4 (basic KDE4),"
- echo " XFCE (basic XFCE), PLASMA5, MATE, CINNAMON."
+ echo " -d desktoptype SLACKWARE (full Slack), KDE4 basic,"
+ echo " XFCE basic, PLASMA5, MATE, CINNAMON, DLACK."
echo " -e Use ISO boot-load-size of 32 for computers."
echo " where the ISO won't boot otherwise."
echo " -f Forced re-generation of all squashfs modules,"
@@ -960,6 +964,7 @@ case "$LIVEDE" in
PLASMA5) MSEQ="${SEQ_PLASMA5}" ;;
MATE) MSEQ="${SEQ_MSB}" ;;
CINNAMON) MSEQ="${SEQ_CIN}" ;;
+ DLACK) MSEQ="${SEQ_DLACK}" ;;
*) if [ -n "${SEQ_CUSTOM}" ]; then
# Custom distribution with a predefined package list:
MSEQ="${SEQ_CUSTOM}"
@@ -1602,6 +1607,21 @@ EOGL
fi # End LIVEDE = PLASMA5
+if [ "$LIVEDE" = "DLACK" ]; then
+
+ # -------------------------------------------------------------------------- #
+ echo "-- Configuring DLACK."
+ # -------------------------------------------------------------------------- #
+
+ # Make sure we start in graphical mode with gdm enabled.
+ ln -sf /lib/systemd/system/graphical.target ${LIVE_ROOTDIR}/etc/systemd/system/default.target
+ ln -sf /lib/systemd/system/gdm.service ${LIVE_ROOTDIR}/etc/systemd/system/display-manager.service
+
+ # Do not show the blueman applet, Gnome3 has its own BlueTooth widget:
+ echo "NotShowIn=GNOME;" >> ${LIVE_ROOTDIR}/etc/xdg/autostart/blueman.desktop
+
+fi # End LIVEDE = DLACK
+
# You can define the function 'custom_config()' by uncommenting it in
# the configuration file 'make_slackware_live.conf'.
if type custom_config 1>/dev/null 2>/dev/null ; then
@@ -1644,6 +1664,8 @@ elif [ "$LIVEDE" = "MATE" ]; then
ln -sf xinitrc.mate-session ${LIVE_ROOTDIR}/etc/X11/xinit/xinitrc
elif [ "$LIVEDE" = "CINNAMON" ]; then
ln -sf xinitrc.cinnamon-session ${LIVE_ROOTDIR}/etc/X11/xinit/xinitrc
+elif [ "$LIVEDE" = "DLACK" ]; then
+ ln -sf xinitrc.gnome ${LIVE_ROOTDIR}/etc/X11/xinit/xinitrc
elif [ -f ${LIVE_ROOTDIR}/etc/X11/xinit/xinitrc.xfce ]; then
ln -sf xinitrc.xfce ${LIVE_ROOTDIR}/etc/X11/xinit/xinitrc
fi
@@ -94,7 +94,7 @@ DISTRO=${DISTRO:-"slackware"}
LIVE_HOSTNAME=${LIVE_HOSTNAME:-"darkstar"}
# What type of Live image?
-# Choices are: SLACKWARE, XFCE, KDE4, PLASMA5, MATE, CINNAMON
+# Choices are: SLACKWARE, XFCE, KDE4, PLASMA5, MATE, CINNAMON, DLACK
LIVEDE=${LIVEDE:-"SLACKWARE"}
# What runlevel to use if adding a DE like: XFCE, KDE4, PLASMA5 etc...